#!/usr/bin/perl

use strict;
use warnings;

use Glib qw(TRUE FALSE);
use Gtk2 '-init';
use Gtk2::StatusIcon;
use Gnome2;

sub update_icon
{
	my $status_icon = shift;

	my ($icon, $tooltip);
	
	if ('file' eq $status_icon->{state}) {
		$icon = 'gnome-fs-regular';
		$tooltip = 'Regular File';
	}
	else {
		$icon = 'gnome-fs-directory';
		$tooltip = 'Directory';
	}

	$status_icon->set_tooltip($tooltip, '');
	
	my $icon_info = $status_icon->{icon_theme}->lookup_icon($icon,
		$status_icon->get_size,
		'use-builtin');
	if ($icon_info) {
		my $pixbuf;
		eval {
			$pixbuf = $icon_info->load_icon;
			1;
		};
		if ($@) {
			warn(sprintf("Failed to load '%s': %s", $icon, $@));
		}
		else {
			$status_icon->set_from_pixbuf($pixbuf);
		}
	}
	else {
		warn(sprintf("Failed to look up icon '%s'", $icon));
	}
}

my $icon = Gtk2::StatusIcon->new;

$icon->{state} = 'file';
$icon->{icon_theme} = Gtk2::IconTheme->get_default;

$icon->signal_connect(activate => sub {
		my $status_icon = shift;

		unless ($status_icon->{dialog}) {
			my $dialog = Gtk2::MessageDialog->new(undef,
				[ 'modal' ],
				'question',
				'close',
				"You wanna test the status icon ?");
			$dialog->signal_connect(response => sub { $_[0]->hide; });
			$dialog->signal_connect(delete_event => sub { $_[0]->hide_on_delete; });
			my $toggle = Gtk2::ToggleButton->new_with_mnemonic("_Blink the icon");
			$dialog->vbox->pack_start($toggle, TRUE, TRUE, 6);
			$toggle->show;
			$toggle->signal_connect(toggled => sub {
					my $toggle = shift;
					$status_icon->set_is_blinking($toggle->get_active);
				});
				
			$status_icon->{dialog} = $dialog;
		}

		$status_icon->{dialog}->present;
	}, $icon);

Glib::Timeout->add(2000, sub {
		my $status_icon = shift;
		if ('file' eq $status_icon->{state}) {
			$status_icon->{state} = 'directory';
		}
		else {
			$status_icon->{state} = 'file';
		}

		update_icon($status_icon);

		return TRUE;
	}, $icon);

Gtk2->main;

0;
